
.. raw:: html

    <style media="screen" type="text/css">
      h1 { display:none; }
      th { display:none; }
    </style>

*******
SNCosmo
*******


.. image:: _static/sncosmo_banner_96.png
    :width: 409px
    :height: 96px

SNCosmo is a Python library for supernova cosmology
analysis. It aims to make such analysis both as flexible and clear as
possible.

.. toctree::
   :maxdepth: 1
   :titlesonly:

   install
   models
   bandpasses
   magsystems
   photdata
   cuts
   simulation
   registry
   configuration
   
.. include:: examples/index.rst

.. toctree::
   :hidden:
   :titlesonly:

   examples/index
   reference
   source-list
   bandpass-list
   magsystem-list

:doc:`reference`
================

More...
=======

.. toctree::
   :maxdepth: 1
   :titlesonly:

   history
   about
   contributing

* Check out the source code: https://github.com/sncosmo/sncosmo
* Report bugs, request features: https://github.com/sncosmo/sncosmo/issues
* User & developer mailing list: https://groups.google.com/forum/#!forum/sncosmo
